A pool represents a group of members over which the load balancing will be applied.

Method: The load balancer algorithm that distributes traffic to the pool members.

- LEAST_CONNECTIONS: Allocates requests to the instance with the least number of active connections.
- ROUND_ROBIN: Rotates requests evenly between multiple instances.
- SOURCE_IP: Requests from a unique source IP address are consistently directed to the same instance.